@@ -9,3 +9,5 @@ from .dishwasher import *
 from .laundry import *
 from .advantium import *
 from .water_filter import *
+from .ac import *
+from .hood import *
\ No newline at end of file
