@@ -19,6 +19,10 @@ class ErdCodeClass(enum.IntFlag):
     PERCENTAGE = auto()
     FLOW_RATE = auto()
     LIQUID_VOLUME = auto()
+    POWER = auto()
+    ENERGY = auto()
+    FAN = auto()
+    LIGHT = auto()
     OVEN_SENSOR = auto()
     FRIDGE_SENSOR = auto()
     FREEZER_SENSOR = auto()
@@ -30,3 +34,5 @@ class ErdCodeClass(enum.IntFlag):
     MICROWAVE_SENSOR = auto()
     ADVANTIUM_SENSOR = auto()
     WATERFILTER_SENSOR = auto()
+    AC_SENSOR = auto()
+    HOOD_SENSOR = auto()
