@@ -117,6 +117,8 @@ class ErdCode(enum.Enum):
     TURBO_COOL_STATUS = "0x100f"
     TURBO_FREEZE_STATUS = "0x100e"
     WATER_FILTER_STATUS = "0x1009"
+    INTERIOR_LIGHT = "0x1024"
+    PROXIMITY_LIGHT = "0x1028"
 
     # Oven codes
     ACTIVE_F_CODE_STATUS = "0x5005"
@@ -127,6 +129,7 @@ class ErdCode(enum.Enum):
     KEY_PRESSED = "0x5006"
     LIGHT_BAR = "0x5002"
     LOWER_OVEN_AVAILABLE_COOK_MODES = "0x520b"
+    LOWER_OVEN_EXTENDED_COOK_MODES = "0x5213"
     LOWER_OVEN_COOK_MODE = "0x5200"
     LOWER_OVEN_COOK_TIME_REMAINING = "0x5204"
     LOWER_OVEN_CURRENT_STATE = "0x5201"
@@ -143,6 +146,7 @@ class ErdCode(enum.Enum):
     OVEN_CONFIGURATION = "0x5007"
     OVEN_MODE_MIN_MAX_TEMP = "0x5008"
     UPPER_OVEN_AVAILABLE_COOK_MODES = "0x510b"
+    UPPER_OVEN_EXTENDED_COOK_MODES = "0x5113"
     UPPER_OVEN_COOK_MODE = "0x5100"
     UPPER_OVEN_COOK_TIME_REMAINING = "0x5104"
     UPPER_OVEN_CURRENT_STATE = "0x5101"
@@ -166,9 +170,7 @@ class ErdCode(enum.Enum):
     PRECISION_COOKING_PROBE_TEMP_TARGET = "0x5672"  # R/W, int 4 places
     PRECISION_COOKING_PROBE_TEMP_CURRENT = "0x5673"
     PRECISION_COOKING_PROBE_TIME_TARGET = "0x5674"  # R/W, int 4 places
-    PRECISION_COOKING_START_SOUS_VIDE_TIMER_ACTIVE_STATUS = (
-        "0x5675"  # R/W, int 2 places
-    )
+    PRECISION_COOKING_START_SOUS_VIDE_TIMER_ACTIVE_STATUS = "0x5675"  # R/W, int 2 places
     PRECISION_COOKING_PROBE_TIME_CURRENT = "0x5676"
     PRECISION_COOKING_PROBE_TARGET_TIME_REACHED = "0x5677"
     PRECISION_COOKING_PROBE_BATTERY_STATUS = "0x5678"
@@ -183,6 +185,13 @@ class ErdCode(enum.Enum):
     # Lots more in 0x5Cxx
 
     # Hood
+    HOOD_TIMER_AVAILABILITY = "0x500f"
+    HOOD_TIMER = "0x5020"
+    HOOD_FAN_SPEED = "0x5b00"
+    HOOD_FAN_SPEED_AVAILABILITY = "0x5b01"
+    HOOD_LIGHT_LEVEL = "0x5b02"
+    HOOD_LIGHT_LEVEL_AVAILABILITY = "0x5b03"
+    HOOD_DELAY_OFF = "0x5b04"
 
     # Advantium
     ADVANTIUM_KITCHEN_TIME_REMAINING = "0x0050"
@@ -214,5 +223,23 @@ class ErdCode(enum.Enum):
     WH_FILTER_LEAK_VALIDITY = "0x116e"
     WH_FILTER_LIFE_REMAINING = "0x1164"
 
+    # AIR CONDITIONER
+    AC_TARGET_TEMPERATURE = "0x7003"
+    AC_FAN_SETTING = "0x7a00"
+    AC_OPERATION_MODE = "0x7a01"
+    AC_AMBIENT_TEMPERATURE = "0x7a02"
+    AC_FILTER_STATUS = "0x7a04"
+    AC_POWER_STATUS = "0x7a0f"
+    AC_UNKNOWN7A12 = "0x7a12"
+
+    #Window AC
+    WAC_DEMAND_RESPONSE_POWER = "0xd005"
+    WAC_DEMAND_RESPONSE_STATE = "0xd006"
+
+    #Split AC
+    SAC_AVAILABLE_MODES = "0x7b00"
+    SAC_SLEEP_MODE = "0x7b05"
+    SAC_TARGET_TEMPERATURE_RANGE = "0x7b06"
+    SAC_AUTO_SWING_MODE = "0x7b07"
 
 ErdCodeType = Union[ErdCode, str]
