@@ -10,4 +10,4 @@ class ErdWaterFilterManualMode(enum.Enum):
         return self.name.replace("_"," ").title()
 
     def boolify(self) -> Optional[bool]:
-        return self.value == ErdWaterFilterManualMode.MANUAL
\ No newline at end of file
+        return self == ErdWaterFilterManualMode.MANUAL
\ No newline at end of file
